@@ -178,6 +178,14 @@ Signing is only possible with addresses of the type 'legacy'.</source>
         <source>Enter the old passphrase and new passphrase for the wallet.</source>
         <translation type="unfinished">വാലെറ്റിന്റെ പഴയ രഹസ്യപദവും പുതിയ രഹസ്യപദവും നൽകുക.</translation>
     </message>
+    <message>
+        <source>Continue</source>
+        <translation type="unfinished">തുടരുക</translation>
+    </message>
+    <message>
+        <source>Back</source>
+        <translation type="unfinished">മടങ്ങിപ്പോവുക</translation>
+    </message>
     <message>
         <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
         <translation type="unfinished">നിങ്ങളുടെ വാലറ്റ് എൻ‌ക്രിപ്റ്റ് ചെയ്യുന്നതിലൂടെ നിങ്ങളുടെ കമ്പ്യൂട്ടറിനെ ബാധിക്കുന്ന ക്ഷുദ്രവെയർ‌ മോഷ്ടിക്കുന്നതിൽ‌ നിന്നും നിങ്ങളുടെ ബിറ്റ്കോയിനുകളെ പൂർണ്ണമായി സംരക്ഷിക്കാൻ‌ കഴിയില്ല.</translation>
@@ -482,6 +490,14 @@ Signing is only possible with addresses of the type 'legacy'.</source>
         <source>Close Wallet…</source>
         <translation type="unfinished">വാലറ്റ് അടയ്ക്കുക</translation>
     </message>
+    <message>
+        <source>Create Wallet…</source>
+        <translation type="unfinished">വാലറ്റ് സൃഷ്ടിക്കുക</translation>
+    </message>
+    <message>
+        <source>Close All Wallets…</source>
+        <translation type="unfinished">എല്ലാ വാലറ്റുകളും അടയ്ക്കുക</translation>
+    </message>
     <message>
         <source>&amp;File</source>
         <translation type="unfinished">&amp; ഫയൽ</translation>
@@ -502,6 +518,10 @@ Signing is only possible with addresses of the type 'legacy'.</source>
         <source>Synchronizing with network…</source>
         <translation type="unfinished"> നെറ്റ്‌വർക്കുമായി സമന്വയിപ്പിക്കുന്നു...</translation>
     </message>
+    <message>
+        <source>Connecting to peers…</source>
+        <translation type="unfinished">സമപ്രായക്കാരുമായി ബന്ധിപ്പിക്കുന്നു...</translation>
+    </message>
     <message>
         <source>Request payments (generates QR codes and bitcoin: URIs)</source>
         <translation type="unfinished">പേയ്‌മെന്റുകൾ അഭ്യർത്ഥിക്കുക (QR കോഡുകളും ബിറ്റ്കോയിനും സൃഷ്ടിക്കുന്നു: URI- കൾ)</translation>
@@ -598,6 +618,10 @@ Signing is only possible with addresses of the type 'legacy'.</source>
         <source>Close all wallets</source>
         <translation type="unfinished">എല്ലാ വാലറ്റുകളും അടയ്‌ക്കുക ...</translation>
     </message>
+    <message>
+        <source>Migrate Wallet</source>
+        <translation type="unfinished">വാലറ്റ് മൈഗ്രേറ്റ് ചെയ്യുക</translation>
+    </message>
     <message>
         <source>Show the %1 help message to get a list with possible Bitcoin command-line options</source>
         <translation type="unfinished">സാധ്യമായ ബിറ്റ്കോയിൻ കമാൻഡ്-ലൈൻ ഓപ്ഷനുകളുള്ള ഒരു ലിസ്റ്റ് ലഭിക്കുന്നതിന് %1 സഹായ സന്ദേശം കാണിക്കുക</translation>
@@ -614,6 +638,11 @@ Signing is only possible with addresses of the type 'legacy'.</source>
         <source>No wallets available</source>
         <translation type="unfinished">വാലറ്റ് ഒന്നും ലഭ്യം അല്ല </translation>
     </message>
+    <message>
+        <source>Wallet Data</source>
+        <extracomment>Name of the wallet data file format.</extracomment>
+        <translation type="unfinished">വാലറ്റ് അടിസ്ഥാനവിവരം</translation>
+    </message>
     <message>
         <source>Load Wallet Backup</source>
         <extracomment>The title for Restore Wallet File Windows</extracomment>
@@ -862,6 +891,13 @@ Signing is only possible with addresses of the type 'legacy'.</source>
         <translation type="unfinished">വാലറ്റ് രൂപീകരണത്തിലെ മുന്നറിയിപ്പ് </translation>
     </message>
     </context>
+<context>
+    <name>MigrateWalletActivity</name>
+    <message>
+        <source>Migrate Wallet</source>
+        <translation type="unfinished">വാലറ്റ് മൈഗ്രേറ്റ് ചെയ്യുക</translation>
+    </message>
+    </context>
 <context>
     <name>OpenWalletActivity</name>
     <message>
@@ -1081,6 +1117,10 @@ Signing is only possible with addresses of the type 'legacy'.</source>
         <source>&amp;Window</source>
         <translation type="unfinished">&amp;ജാലകം </translation>
     </message>
+    <message>
+        <source>Continue</source>
+        <translation type="unfinished">തുടരുക</translation>
+    </message>
     <message>
         <source>Error</source>
         <translation type="unfinished">പിശക് </translation>
@@ -1490,6 +1530,11 @@ Signing is only possible with addresses of the type 'legacy'.</source>
         <source>Export the data in the current tab to a file</source>
         <translation type="unfinished">നിലവിലുള്ള  ടാബിലെ  വിവരങ്ങൾ ഒരു ഫയലിലേക്ക് എക്സ്പോർട്ട് ചെയ്യുക</translation>
     </message>
+    <message>
+        <source>Wallet Data</source>
+        <extracomment>Name of the wallet data file format.</extracomment>
+        <translation type="unfinished">വാലറ്റ് അടിസ്ഥാനവിവരം</translation>
+    </message>
     </context>
 <context>
     <name>bitcoin-core</name>
